# This file is part of CloudControl.
#
# CloudControl is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CloudControl is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with CloudControl.  If not, see <http://www.gnu.org/licenses/>.


""" The **core** package contains all classes used by both client mode and
    server mode.

This packages export following function/classes:

 * :class:`RpcConnection` which handle the connection to the peer.
 * :class:`RpcCaller`, :class:`ThreadedRpcCaller`: which are used internally
   by rpc protocol to execute handlers' functions.
 * :class:`RpcError` which is the exception raised by rpc to wrap remote-side
   exceptions.
 * :class:`AsyncWatcher` which allow to make asynchronous calls.

It also contains a sub-package containing protocols: :mod:`core.protocols`.
"""

from __future__ import absolute_import

from sjrpc.core.rpcconnection import *
from sjrpc.core.exceptions import *
from sjrpc.core.async import *

__all__ = ('RpcConnection', 'RpcError', 'AsyncWatcher')
